@@ -53,7 +53,7 @@ qx.Class.define("callbackery.ui.form.Auto", {
         structure.forEach(function(s){
             var note = s.note ? { note: this['tr'](s.note) } : null;
             if (s.widget == 'header') {
-                form.addGroupHeader(s.label,note);
+                form.addGroupHeader(s.label != null ? this['tr'](s.label) : null,note);
                 return;
             }
 
@@ -108,6 +108,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
                             controller.bindProperty('title', 'label', null, item, index);
                         }
                     });
+                    cfg.structure.forEach(function(item){
+                        item.title = item.title != null ? this['tr'](item.title) : null;
+                    },this);
                     var sbModel = qx.data.marshal.Json.createModel(cfg.structure ||
                     [ {
                         title : '',
@@ -120,6 +123,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
                 case 'comboBox':
                     control = new qx.ui.form.ComboBox();
                     var ctrl = this._boxCtrl[s.key] = new qx.data.controller.List(null, control);
+                    cfg.structure.forEach(function(item){
+                        item = item != null ? this['tr'](item) : null;
+                    },this);
                     var sbModel = qx.data.marshal.Json.createModel(cfg.structure || []);
                     ctrl.setModel(sbModel);
                     break;
