@@ -1,7 +1,9 @@
 package Mojolicious::Command::generate::callbackery_app;
 use Mojo::Base 'Mojolicious::Command';
 use File::Basename;
-use Mojo::Util qw(class_to_file class_to_path slurp);
+use Mojo::Util qw(class_to_file class_to_path);
+use Mojo::File;
+
 use POSIX qw(strftime);
 use Cwd 'getcwd';
 use File::Spec::Functions qw(catdir catfile);
@@ -75,7 +77,7 @@ EOF
     my $email = $userName.'@'.$domain;
 
     if ( -r $ENV{HOME} . '/.gitconfig' ){
-        my $in = slurp $ENV{HOME} . '/.gitconfig';
+        my $in = Mojo::File->path($ENV{HOME} . '/.gitconfig')->slurp;
         $in =~ /name\s*=\s*(\S.+\S)/ and $fullName = $1;
         $in =~ /email\s*=\s*(\S+)/ and $email = $1;
     }
@@ -111,7 +113,7 @@ EOF
 sub render_data {
   my ($self, $name) = (shift, shift);
     Mojo::Template->new->name("template $name")
-    ->render(slurp(dirname($INC{'Mojolicious/Command/generate/callbackery_app.pm'}).'/callbackery_app/'.$name), @_);
+    ->render(Mojo::File->path(dirname($INC{'Mojolicious/Command/generate/callbackery_app.pm'}).'/callbackery_app/'.$name)->slurp, @_);
 }
 1;
 
